@@ -36,3 +36,8 @@ def serve_directory(dir,server_address=("0.0.0.0",300),server_cls=ThreadingTCPSe
 	"""Convenience function. Makes a subclass of FileBasedSpartanHandler with the root attribute set to dir, and passes it to serve."""
 	handler = type("DirectoryServer",(FileBasedSpartanHandler,),{"root":dir})
 	return serve(handler,server_address,server_cls,timeout_interval,ret)
+
+def serve_multiple(handlers,server_address=("0.0.0.0",300),server_cls=ThreadingTCPServer,timeout_interval=0.5,ret=False):
+	"""Convenience function. Makes a subclass of VHostSpartanHandler with the HOSTS attribute set to handlers, and passes it to serve."""
+	handler = type("VHostServer",(VHostSpartanHandler,),{"HOSTS":handlers})
+	return serve(handler,server_address,server_cls,timeout_interval,ret)
